4.42. umbra.ui.inputAccelerators — Umbra 1.0.9 documentation

# 4.42. umbra.ui.inputAccelerators

inputAccelerators.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the Application input accelerators objects.

Others:

## 4.42.1. Module Attributes

`umbra.ui.inputAccelerators.` `LOGGER`

## 4.42.2. Functions

`umbra.ui.inputAccelerators.` `getEditorCapability`(editor, capability)

  Returns given editor capability.

  Parameters: | editor (QWidget) – Document editor. capability (unicode) – Capability to retrieve.
  Returns: | Capability.
  Return type: | object

`umbra.ui.inputAccelerators.` `isSymbolsPairComplete`(editor, symbol)

  Returns if the symbols pair is complete on current editor line.

  Parameters: | editor (QWidget) – Document editor. symbol (unicode) – Symbol to check.
  Returns: | Is symbols pair complete.
  Return type: | bool

`umbra.ui.inputAccelerators.` `performCompletion`(editor)

  Performs the completion on given editor.

  Parameters: | editor (QWidget) – Document editor.
  Returns: | Method success.
  Return type: | bool

`umbra.ui.inputAccelerators.` `indentationPreEventInputAccelerators`(editor, event)

  Implements indentation pre event input accelerators.

  Parameters: | editor (QWidget) – Document editor. event (QEvent) – Event being handled.
  Returns: | Process event.
  Return type: | bool

`umbra.ui.inputAccelerators.` `indentationPostEventInputAccelerators`(editor, event)

  Implements indentation post event input accelerators.

  Parameters: | editor (QWidget) – Document editor. event (QEvent) – Event being handled.
  Returns: | Method success.
  Return type: | bool

`umbra.ui.inputAccelerators.` `completionPreEventInputAccelerators`(editor, event)

  Implements completion pre event input accelerators.

  Parameters: | editor (QWidget) – Document editor. event (QEvent) – Event being handled.
  Returns: | Process event.
  Return type: | bool

`umbra.ui.inputAccelerators.` `completionPostEventInputAccelerators`(editor, event)

  Implements completion post event input accelerators.

  Parameters: | editor (QWidget) – Document editor. event (QEvent) – Event being handled.
  Returns: | Process event.
  Return type: | bool

`umbra.ui.inputAccelerators.` `symbolsExpandingPreEventInputAccelerators`(editor, event)

  Implements symbols expanding pre event input accelerators.

  Parameters: | editor (QWidget) – Document editor. event (QEvent) – Event being handled.
  Returns: | Process event.
  Return type: | bool